@@ -1,5 +1,5 @@
 #
-# Copyright 2011-2016 Red Hat, Inc.
+# Copyright 2011-2017 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,19 +28,16 @@ import os
 import subprocess
 import threading
 
-from contextlib import nested
-
-import sanlock
-
 from vdsm import constants
 from vdsm import utils
-from vdsm import concurrent
 
+from vdsm.common import concurrent
 from vdsm.common import errors
 from vdsm.common import osutils
 from vdsm.config import config
 from vdsm.storage import exception as se
 from vdsm.storage import misc
+from vdsm.storage.compat import sanlock
 
 
 MAX_HOST_ID = 250
@@ -267,7 +264,6 @@ class SANLock(object):
         self._lock = threading.Lock()
         self._sdUUID = sdUUID
         self._idsPath = idsPath
-        self._sanlockfd = None
         self._ready = concurrent.ValidatingEvent()
 
     @property
@@ -392,7 +388,7 @@ class SANLock(object):
                 "Timeout acquiring host id, cannot acquire %s (id=%s)"
                 % (lease, hostId))
 
-        with nested(self._lock, SANLock._sanlock_lock):
+        with self._lock, SANLock._sanlock_lock:
             while True:
                 if SANLock._sanlock_fd is None:
                     try:
@@ -445,7 +441,6 @@ class SANLock(object):
             except sanlock.SanlockException as e:
                 raise se.ReleaseLockFailure(self._sdUUID, e)
 
-            self._sanlockfd = None
         self.log.info("Successfully released %s", lease)
 
 
