@@ -12,19 +12,13 @@ function terminate_jobs {
 
 trap terminate_jobs EXIT
 
-if [ -z "$NOSE_EVAL_ATTR" ]; then
-    NOSE_EVAL_ATTR="type!='functional'"
-else
-    NOSE_EVAL_ATTR+=" and type!='functional'"
-fi
-
 export \
     LC_ALL=C \
     NOSE_EVAL_ATTR \
     NOSE_LOGFORMAT='%(asctime)s %(levelname)-5s (%(threadName)s) [%(name)s] %(message)s (%(module)s:%(lineno)d)' \
     NOSE_VERBOSE=${NOSE_VERBOSE:-3} \
     PYTHONDONTWRITEBYTECODE=1 \
-    PYTHONPATH="../lib:../vdsm:../client:../vdsm_api:$PYTHONPATH" \
+    PYTHONPATH="../static/usr/share/vdsm:../lib:../vdsm_api:$PYTHONPATH" \
     $NULL
 
 "$PYTHON_EXE" ../tests/testrunner.py --local-modules $@ &
